hooks_runner library
Classes
- BuildResult
- The result of executing build hooks from all packages in the dependency tree of the entry point application.
-
Failure<
E> - The failed outcome of an operation, containing the error value.
- KernelAsset
- KernelAssetAbsolutePath
- Asset at absolute path uri on the target device where Dart is run.
- KernelAssetInExecutable
-
Asset is embedded in executable and symbols are available through
DynamicLibrary.executable(). - KernelAssetInProcess
-
Asset is loaded in the process and symbols are available through
DynamicLibrary.process(). - KernelAssetPath
- KernelAssetRelativePath
- Asset at relative path uri, relative to the 'dart file' executed.
- KernelAssets
- KernelAssetSystemPath
-
Asset is available on the system
PATH. - LinkResult
- The result of executing the link hooks from all packages in the dependency tree of the entry point application.
- NativeAssetsBuildRunner
- The programmatic API to be used by Dart launchers to invoke native builds.
- PackageLayout
- Directory layout for dealing with native assets.
- RecordUseConfig
-
The configuration for the recorded use file (
package:record_use) used in link hooks. -
Result<
S, E> -
The outcome of an operation that can either succeed with a value of type
Sor fail with an error of typeE. -
Success<
S> - The successful outcome of an operation, containing the value.
- Target
- UserDefines
- The user-defines information passed from the SDK to the NativeAssetsBuildRunner.
Enums
- HooksRunnerFailure
-
A failure that occurred during a NativeAssetsBuildRunner
buildorlink.
Typedefs
- BuildInputCreator = BuildInputBuilder Function()
- LinkInputCreator = LinkInputBuilder Function()